@@ -562,5 +562,24 @@ def list_display_admin_register(cls):
 
 
 class BaseAdmin(ListDisplayAdmin):
-    pass
+    def changelist_view(self, request, extra_context=None):
+        """
+        这里想跳过"必须选择一个数据"的确认框,
+        但django原生admin可以, 而simpleui无法实现,
+        经过改进后, 以"fc_"开头的方法将强制运行
+
+        - https://stackoverflow.com/questions/4500924/django-admin-action-without-selecting-objects
+        """
+        from django.contrib.admin.helpers import ACTION_CHECKBOX_NAME
+        MyModel = self.model
+
+        # 强制运行以"fc_"开头的action
+        if 'action' in request.POST and request.POST['action'].startswith('fc_'):
+            if not request.POST.getlist(ACTION_CHECKBOX_NAME):
+                post = request.POST.copy()
+                for u in MyModel.objects.all():
+                    post.update({ACTION_CHECKBOX_NAME: str(u.id)})
+                request._set_post(post)
+        return super().changelist_view(request, extra_context)
+
 
